@@ -583,7 +583,9 @@ class DataTransform(forms.ModelForm):
 
         super(DataTransform, self).__init__(*args, **kwargs)
         if self.fields['parent'] is not None and self.fields['parent'] != '':
-            self.fields['accessory'].initial = str(DataTransformer.objects.get(self.fields['parent'].initial).accessory.pk)
+            print(str(self.fields['parent']))
+            print(str(self.fields['parent'].initial))
+            self.fields['accessory'].initial = str(DataTransformer.objects.get(self.fields['parent'].initial.pk).first().accessory.pk)
 
         try:
             if self.instance.get_children().count() >= 0:
