@@ -362,7 +362,7 @@ class DataTransformer(MPTTModel):
 class DataTransformerConstants(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True)
-    index = models.IntegerField(blank=True,null=True)
+    index = models.IntegerField(blank=True, null=True, default=None)
     value = models.FloatField(blank=True,null=False)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -405,7 +405,7 @@ class HardwareStatsDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
     hardware_stat = models.ForeignKey(HardwareStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True)
-    index = models.IntegerField()
+    index = models.IntegerField(blank=True, null=True, default=None)
     updated_at = models.DateTimeField(blank=True,auto_now=True)
     created_at = models.DateTimeField(blank=True,auto_now_add=True)
 
